@@ -2,10 +2,15 @@
 
 # Check internet connection (only works on unix-alike)
 checkInternet <- function(site = "www.r-project.org") {
-  .Platform$OS.type == "unix" && !is.null(suppressWarnings(utils::nsl(site)))
+  os <- .Platform$OS.type
+  if (os == "windows") {
+    return(NA)
+  }
+  hasInternet <- !is.null(suppressWarnings(utils::nsl(site)))
+  if (!hasInternet) message("No internet connection")
+  return(invisible(hasInternet))
 }
-hasInternet <- checkInternet()
-if (!hasInternet) message("No internet connection")
+checkInternet()
 
 # Only run all tests if using a development version (which has 4 components,
 # e.g. 0.0.0.1). CRAN releases have the standard 3 component version. This
